EDS Trend (Pure Web)

# EDS Trend

Fetch and plot trend data from the EDS server.

## 1. Sensor Selection (IDCS)

Separate IDCS with spaces or commas (e.g., M100FI M310LI FI8001).

Use Configured Default IDCS
2. Time Range

You can define start/end or days. Defaults to last 48h.

Start Time
End Time
Days to Plot
3. Advanced Data Options

Defaults to ~400 data points. You can specify the time delta between points, or choose the number of points.

Seconds Between Points
Datapoint Count
4. Plotting Method

Choose how the plot will show. Plotly is best for cross-platform.

Plotly Web Plot (Recommended) Matplotlib (Legacy)